<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="100px"
    >
      <el-form-item label="搜索" prop="zjhm">
        <el-input
          v-model="queryParams.zjhm"
          placeholder="请输入搜索内容"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >查询</el-button
        >
        <el-button
          type="primary"
          icon="el-icon-plus"
          size="mini"
          @click="addPlan"
          >添加</el-button
        >
        <el-button
          type="primary"
          icon="el-icon-edit"
          size="mini"
          >修改</el-button
        >
        <el-button
          type="primary"
          icon="el-icon-delete"
          size="mini"
          @click="del"
          >删除</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>
    <el-table v-loading="loading" :data="senHistoryList" border>
      <el-table-column
        label="备注"
        align="center"
        prop="jdsj"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="反馈渠道"
        align="center"
        prop="jdsj"
        :show-overflow-tooltip="true"
      />
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
        width="80"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['web:tags:edit']"
            title="修改"
          ></el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['web:tags:remove']"
            title="删除"
          ></el-button>
        </template>
      </el-table-column>
    </el-table>

    <el-dialog title="我的汇报" :visible.sync="dialog">
      <!-- 表单内容 -->
      <el-form>
        <el-form-item label="汇报主题" label-width="100px">
          <el-input autocomplete="off" class="input"></el-input>
        </el-form-item>
        <el-form-item label="允许查看人" label-width="100px">
          <el-input autocomplete="off" class="input"></el-input>
        </el-form-item>
        <el-form-item label="上传附件" label-width="100px">
          <FileUpload></FileUpload>
        </el-form-item>
        <el-form-item label="汇报内容" label-width="100px">
          <Tinymce class="setTinymce" :height="200" v-model="value"></Tinymce>
        </el-form-item>
      </el-form>
      
      <div slot="footer" class="dialog-footer">
        <el-button @click="closeDialog">取 消</el-button>
        <el-button type="primary" @click="submitForm">确 定</el-button>
      </div>
    </el-dialog>

    <div class="pag">
      <div class="pag1">
        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>
  </div>
</template>

<script>
import Tinymce from "@/components/Tinymce.vue";
export default {
  components: {
    Tinymce,
  },
  data() {
    return {
      senHistoryList: [],
      // 遮罩层
      loading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        name: "",
        phone: "",
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
      dialog: false,
    };
  },

  methods: {
    addPlan() {
      this.dialog = true;
    },
    closeDialog() {
      this.dialog = false;
    },
    /** 查询宣教对应标签列表 */
    getList() {
      this.loading = false;
    },
    handleAdd() {},
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {};
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 删除按钮操作 */
    del(){
      console.log("删除");
    },
    /** 提交按钮操作 */
    submitForm() {
      console.log("表单提交");
      this.closeDialog(); // 提交后关闭弹框
    },
  },
};
</script>

<style scoped lang="scss">
.input {
  width: 250px;
}
</style>